fabulist package
================

.. toctree::
   :maxdepth: 3

   fabulist_module
   lorem_ipsum_module

.. comment:
  fabulist module
  ---------------

  .. automodule:: fabulist.fabulist
      :members: Fabulist
      :undoc-members:
      :private-members:
      :show-inheritance:

  lorem_ipsum module
  ------------------

  .. automodule:: fabulist.lorem_ipsum
      :members: LoremGenerator
      :undoc-members:
      :private-members:
      :show-inheritance:
